import { isEqual } from 'lodash-es';
import { useState } from 'react';
import styles from './ColorPicker.module.css';
import { HSegmentedControl } from './HSegmentedControl';
import { HslAssemble } from './HslAsssemble';
import { RGBAssemble } from './RGBAssemble';

export function ColorPicker() {
  const [pickMode, setMode] = useState<'rgb' | 'hsl' | 'oklch'>('rgb');
  const [selectedColor, setSelectedColor] = useState<string>('000000');

  return (
    <div className={styles.color_picker}>
      <div className={styles.color_preview} style={{ backgroundColor: `#${selectedColor}` }} />
      <div className={styles.color_code}>#{selectedColor}</div>
      <HSegmentedControl
        options={[
          { label: 'RGB', value: 'rgb' },
          { label: 'HSL', value: 'hsl' },
        ]}
        value={pickMode}
        onChange={(value) => setMode(value as 'rgb' | 'hsl' | 'oklch')}
      />
      {isEqual(pickMode, 'rgb') && (
        <RGBAssemble color={selectedColor} onChange={(c) => setSelectedColor(c)} />
      )}
      {isEqual(pickMode, 'hsl') && (
        <HslAssemble color={selectedColor} onChange={(c) => setSelectedColor(c)} />
      )}
    </div>
  );
}
